@@ -20,21 +20,28 @@
 
 /**
  * SECTION:element-siddec
+ * @short_description: a decoder for sid files
  *
+ * <refsect2>
+ * <para>
  * This element decodes .sid files to raw audio. .sid files are in fact 
  * small Commodore 64 programs that are executed on an emulated 6502 CPU and a 
- * MOS 6581 sound chip.
- * 
+ * MOS 6581 sound chip. 
+ * </para>
+ * <para>
  * This plugin will first load the complete program into memory before starting
  * the emulator and producing output.
- * 
+ * </para>
+ * <para>
  * Seeking is not (and cannot be) implemented.
- * 
- * <refsect2>
+ * </para>
  * <title>Example pipelines</title>
- * |[
+ * <para>
+ * <programlisting>
  * gst-launch -v filesrc location=Hawkeye.sid ! siddec ! audioconvert ! alsasink
- * ]| Decode a sid file and play back the audio using alsasink.
+ * </programlisting>
+ * Decode a sid file and play back the audio using alsasink.
+ * </para>
  * </refsect2>
  *
  * Last reviewed on 2006-12-30 (0.10.5)
@@ -47,6 +54,19 @@
 #include <string.h>
 #include "gstsiddec.h"
 
+static const GstElementDetails gst_siddec_details =
+GST_ELEMENT_DETAILS ("Sid decoder",
+    "Codec/Decoder/Audio",
+    "Use libsidplay to decode SID audio tunes",
+    "Wim Taymans <wim@fluendo.com> ");
+
+/* Sidec signals and args */
+enum
+{
+  /* FILL ME */
+  LAST_SIGNAL
+};
+
 #define DEFAULT_TUNE		0
 #define DEFAULT_CLOCK		SIDTUNE_CLOCK_PAL
 #define DEFAULT_MEMORY		MPU_BANK_SWITCHING
@@ -87,8 +107,6 @@ static GstStaticPadTemplate src_templ = GST_STATIC_PAD_TEMPLATE ("src",
         "rate = (int) [ 8000, 48000 ], " "channels = (int) [ 1, 2 ]")
     );
 
-GST_DEBUG_CATEGORY_STATIC (gst_siddec_debug);
-#define GST_CAT_DEFAULT gst_siddec_debug
 
 #define GST_TYPE_SID_CLOCK (gst_sid_clock_get_type())
 static GType
@@ -125,6 +143,9 @@ gst_sid_memory_get_type (void)
   return sid_memory_type;
 }
 
+static void gst_siddec_base_init (gpointer g_class);
+static void gst_siddec_class_init (GstSidDec * klass);
+static void gst_siddec_init (GstSidDec * siddec);
 static void gst_siddec_finalize (GObject * object);
 
 static GstFlowReturn gst_siddec_chain (GstPad * pad, GstBuffer * buffer);
@@ -140,33 +161,60 @@ static void gst_siddec_get_property (GObject * object, guint prop_id,
 static void gst_siddec_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
 
-#define _do_init(bla) \
-    GST_DEBUG_CATEGORY_INIT (gst_siddec_debug, "siddec", 0, "C64 sid song player");
+static GstElementClass *parent_class = NULL;
 
-GST_BOILERPLATE_FULL (GstSidDec, gst_siddec, GstElement, GST_TYPE_ELEMENT, 
-    _do_init);
+//static guint gst_siddec_signals[LAST_SIGNAL] = { 0 };
+
+GType
+gst_siddec_get_type (void)
+{
+  static GType siddec_type = 0;
+
+  if (G_UNLIKELY (siddec_type == 0)) {
+    static const GTypeInfo siddec_info = {
+      sizeof (GstSidDecClass),
+      gst_siddec_base_init,
+      NULL,
+      (GClassInitFunc) gst_siddec_class_init,
+      NULL,
+      NULL,
+      sizeof (GstSidDec),
+      0,
+      (GInstanceInitFunc) gst_siddec_init,
+      NULL
+    };
+
+    siddec_type =
+        g_type_register_static (GST_TYPE_ELEMENT, "GstSidDec", &siddec_info,
+        (GTypeFlags) 0);
+  }
+
+  return siddec_type;
+}
 
 static void
 gst_siddec_base_init (gpointer g_class)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
 
-  gst_element_class_set_details_simple (element_class, "Sid decoder",
-      "Codec/Decoder/Audio", "Use libsidplay to decode SID audio tunes",
-      "Wim Taymans <wim.taymans@gmail.com>");
+  gst_element_class_set_details (element_class, &gst_siddec_details);
 
-  gst_element_class_add_static_pad_template (element_class,
-      &src_templ);
-  gst_element_class_add_static_pad_template (element_class,
-      &sink_templ);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&src_templ));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&sink_templ));
 }
 
 static void
-gst_siddec_class_init (GstSidDecClass * klass)
+gst_siddec_class_init (GstSidDec * klass)
 {
   GObjectClass *gobject_class;
+  GstElementClass *gstelement_class;
 
   gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
+
+  parent_class = GST_ELEMENT_CLASS (g_type_class_peek_parent (klass));
 
   gobject_class->finalize = gst_siddec_finalize;
   gobject_class->set_property = gst_siddec_set_property;
@@ -174,49 +222,49 @@ gst_siddec_class_init (GstSidDecClass * klass)
 
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_TUNE,
       g_param_spec_int ("tune", "tune", "tune",
-          0, 100, DEFAULT_TUNE,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+          0, 100, DEFAULT_TUNE, (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_CLOCK,
       g_param_spec_enum ("clock", "clock", "clock",
-          GST_TYPE_SID_CLOCK, DEFAULT_CLOCK,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+          GST_TYPE_SID_CLOCK, DEFAULT_CLOCK, (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_MEMORY,
       g_param_spec_enum ("memory", "memory", "memory", GST_TYPE_SID_MEMORY,
-          DEFAULT_MEMORY,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+          DEFAULT_MEMORY, (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_FILTER,
       g_param_spec_boolean ("filter", "filter", "filter", DEFAULT_FILTER,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+          (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_MEASURED_VOLUME,
-      g_param_spec_boolean ("measured-volume", "measured_volume",
+      g_param_spec_boolean ("measured_volume", "measured_volume",
           "measured_volume", DEFAULT_MEASURED_VOLUME,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+          (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_MOS8580,
       g_param_spec_boolean ("mos8580", "mos8580", "mos8580", DEFAULT_MOS8580,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+          (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_FORCE_SPEED,
-      g_param_spec_boolean ("force-speed", "force_speed", "force_speed",
-          DEFAULT_FORCE_SPEED,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+      g_param_spec_boolean ("force_speed", "force_speed", "force_speed",
+          DEFAULT_FORCE_SPEED, (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_BLOCKSIZE,
       g_param_spec_ulong ("blocksize", "Block size",
           "Size in bytes to output per buffer", 1, G_MAXULONG,
-          DEFAULT_BLOCKSIZE,
-          (GParamFlags)(G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)));
+          DEFAULT_BLOCKSIZE, (GParamFlags) G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_METADATA,
       g_param_spec_boxed ("metadata", "Metadata", "Metadata", GST_TYPE_CAPS,
-          (GParamFlags)(G_PARAM_READABLE | G_PARAM_STATIC_STRINGS)));
+          (GParamFlags) G_PARAM_READABLE));
 }
 
 static void
-gst_siddec_init (GstSidDec * siddec, GstSidDecClass * klass)
+gst_siddec_init (GstSidDec * siddec)
 {
-  siddec->sinkpad = gst_pad_new_from_static_template (&sink_templ, "sink");
+  siddec->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get (&sink_templ),
+      "sink");
+  gst_pad_set_query_function (siddec->sinkpad, NULL);
   gst_pad_set_event_function (siddec->sinkpad, gst_siddec_sink_event);
   gst_pad_set_chain_function (siddec->sinkpad, gst_siddec_chain);
   gst_element_add_pad (GST_ELEMENT (siddec), siddec->sinkpad);
 
-  siddec->srcpad = gst_pad_new_from_static_template (&src_templ, "src");
+  siddec->srcpad =
+      gst_pad_new_from_template (gst_static_pad_template_get (&src_templ),
+      "src");
   gst_pad_set_event_function (siddec->srcpad, gst_siddec_src_event);
   gst_pad_set_query_function (siddec->srcpad, gst_siddec_src_query);
   gst_pad_use_fixed_caps (siddec->srcpad);
@@ -268,15 +316,15 @@ update_tags (GstSidDec * siddec)
 
     if (info.nameString) {
       gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-          GST_TAG_TITLE, info.nameString, (void *) NULL);
+          GST_TAG_TITLE, info.nameString, NULL);
     }
     if (info.authorString) {
       gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-          GST_TAG_ARTIST, info.authorString, (void *) NULL);
+          GST_TAG_ARTIST, info.authorString, NULL);
     }
     if (info.copyrightString) {
       gst_tag_list_add (list, GST_TAG_MERGE_REPLACE,
-          GST_TAG_COPYRIGHT, info.copyrightString, (void *) NULL);
+          GST_TAG_COPYRIGHT, info.copyrightString, NULL);
     }
     gst_element_found_tags_for_pad (GST_ELEMENT_CAST (siddec),
         siddec->srcpad, list);
@@ -406,18 +454,20 @@ pause:
   {
     const gchar *reason = gst_flow_get_name (ret);
 
-    if (ret == GST_FLOW_UNEXPECTED) {
-      /* perform EOS logic, FIXME, segment seek? */
-      gst_pad_push_event (pad, gst_event_new_eos ());
-    } else  if (ret < GST_FLOW_UNEXPECTED || ret == GST_FLOW_NOT_LINKED) {
-      /* for fatal errors we post an error message */
-      GST_ELEMENT_ERROR (siddec, STREAM, FAILED,
-          (NULL), ("streaming task paused, reason %s", reason));
-      gst_pad_push_event (pad, gst_event_new_eos ());
-    }
-
-    GST_INFO_OBJECT (siddec, "pausing task, reason: %s", reason);
+    GST_DEBUG_OBJECT (siddec, "pausing task, reason %s", reason);
     gst_pad_pause_task (pad);
+
+    if (GST_FLOW_IS_FATAL (ret) || ret == GST_FLOW_NOT_LINKED) {
+      if (ret == GST_FLOW_UNEXPECTED) {
+        /* perform EOS logic, FIXME, segment seek? */
+        gst_pad_push_event (pad, gst_event_new_eos ());
+      } else {
+        /* for fatal errors we post an error message */
+        GST_ELEMENT_ERROR (siddec, STREAM, FAILED,
+            (NULL), ("streaming task paused, reason %s", reason));
+        gst_pad_push_event (pad, gst_event_new_eos ());
+      }
+    }
     goto done;
   }
 }
@@ -658,7 +708,9 @@ static void
 gst_siddec_set_property (GObject * object, guint prop_id, const GValue * value,
     GParamSpec * pspec)
 {
-  GstSidDec *siddec = GST_SIDDEC (object);
+  GstSidDec *siddec;
+
+  siddec = GST_SIDDEC (object);
 
   switch (prop_id) {
     case PROP_TUNE:
@@ -686,7 +738,7 @@ gst_siddec_set_property (GObject * object, guint prop_id, const GValue * value,
       siddec->config->forceSongSpeed = g_value_get_boolean (value);
       break;
     default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      /* G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec); */
       return;
   }
   siddec->engine->setConfig (*siddec->config);
@@ -696,7 +748,9 @@ static void
 gst_siddec_get_property (GObject * object, guint prop_id, GValue * value,
     GParamSpec * pspec)
 {
-  GstSidDec *siddec = GST_SIDDEC (object);
+  GstSidDec *siddec;
+
+  siddec = GST_SIDDEC (object);
 
   switch (prop_id) {
     case PROP_TUNE:
@@ -727,7 +781,7 @@ gst_siddec_get_property (GObject * object, guint prop_id, GValue * value,
       g_value_set_boxed (value, NULL);
       break;
     default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      /* G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec); */
       break;
   }
 }
