@@ -25,7 +25,6 @@
 #endif
 
 #include "gstdvdsubdec.h"
-#include "gstdvdsubparse.h"
 #include <string.h>
 
 GST_BOILERPLATE (GstDvdSubDec, gst_dvd_sub_dec, GstElement, GST_TYPE_ELEMENT);
@@ -40,21 +39,22 @@ static void gst_setup_palette (GstDvdSubDec * dec);
 static void gst_dvd_sub_dec_merge_title (GstDvdSubDec * dec, GstBuffer * buf);
 static GstClockTime gst_dvd_sub_dec_get_event_delay (GstDvdSubDec * dec);
 static gboolean gst_dvd_sub_dec_sink_event (GstPad * pad, GstEvent * event);
-static gboolean gst_dvd_sub_dec_sink_setcaps (GstPad * pad, GstCaps * caps);
 
 static GstFlowReturn gst_send_subtitle_frame (GstDvdSubDec * dec,
     GstClockTime end_ts);
 
+static const GstElementDetails gst_dvd_sub_dec_details =
+GST_ELEMENT_DETAILS ("DVD subtitle Decoder",
+    "Codec/Decoder/Video",
+    "Decodes DVD subtitles into AYUV video frames",
+    "Wim Taymans <wim.taymans@chello.be>, "
+    "Jan Schmidt <thaytan@mad.scientist.com>");
+
 static GstStaticPadTemplate src_template = GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("video/x-raw-yuv, format = (fourcc) AYUV, "
-        "width = (int) 720, height = (int) 576, framerate = (fraction) 0/1; "
-        "video/x-raw-rgb, "
-        "width = (int) 720, height = (int) 576, framerate = (fraction) 0/1, "
-        "bpp = (int) 32, endianness = (int) 4321, red_mask = (int) 16711680, "
-        "green_mask = (int) 65280, blue_mask = (int) 255, "
-        " alpha_mask = (int) -16777216, depth = (int) 32")
+        "width = (int) 720, height = (int) 576, framerate = (fraction) 0/1")
     );
 
 static GstStaticPadTemplate subtitle_template = GST_STATIC_PAD_TEMPLATE ("sink",
@@ -105,22 +105,22 @@ gst_dvd_sub_dec_base_init (gpointer klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_add_static_pad_template (element_class, &src_template);
-  gst_element_class_add_static_pad_template (element_class,
-      &subtitle_template);
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&src_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&subtitle_template));
 
-  gst_element_class_set_details_simple (element_class, "DVD subtitle decoder",
-      "Codec/Decoder/Video", "Decodes DVD subtitles into AYUV video frames",
-      "Wim Taymans <wim.taymans@gmail.com>, "
-      "Jan Schmidt <thaytan@mad.scientist.com>");
+  gst_element_class_set_details (element_class, &gst_dvd_sub_dec_details);
 }
 
 static void
 gst_dvd_sub_dec_class_init (GstDvdSubDecClass * klass)
 {
   GObjectClass *gobject_class;
+  GstElementClass *gstelement_class;
 
   gobject_class = (GObjectClass *) klass;
+  gstelement_class = (GstElementClass *) klass;
 
   gobject_class->finalize = gst_dvd_sub_dec_finalize;
 }
@@ -130,19 +130,21 @@ gst_dvd_sub_dec_init (GstDvdSubDec * dec, GstDvdSubDecClass * klass)
 {
   GstPadTemplate *tmpl;
 
-  dec->sinkpad = gst_pad_new_from_static_template (&subtitle_template, "sink");
+  dec->sinkpad =
+      gst_pad_new_from_template (gst_static_pad_template_get
+      (&subtitle_template), "sink");
   gst_pad_set_chain_function (dec->sinkpad,
       GST_DEBUG_FUNCPTR (gst_dvd_sub_dec_chain));
   gst_pad_set_event_function (dec->sinkpad,
       GST_DEBUG_FUNCPTR (gst_dvd_sub_dec_sink_event));
   gst_element_add_pad (GST_ELEMENT (dec), dec->sinkpad);
-  gst_pad_set_setcaps_function (dec->sinkpad, gst_dvd_sub_dec_sink_setcaps);
 
   tmpl = gst_static_pad_template_get (&src_template);
   dec->srcpad = gst_pad_new_from_template (tmpl, "src");
   gst_pad_set_event_function (dec->srcpad,
       GST_DEBUG_FUNCPTR (gst_dvd_sub_dec_src_event));
   gst_pad_use_fixed_caps (dec->srcpad);
+  gst_pad_set_caps (dec->srcpad, gst_pad_template_get_caps (tmpl));
   gst_object_unref (tmpl);
   gst_element_add_pad (GST_ELEMENT (dec), dec->srcpad);
 
@@ -156,6 +158,10 @@ gst_dvd_sub_dec_init (GstDvdSubDec * dec, GstDvdSubDecClass * klass)
   dec->forced_display = FALSE;
   dec->visible = FALSE;
 
+  memset (dec->menu_index, 0, sizeof (dec->menu_index));
+  memset (dec->menu_alpha, 0, sizeof (dec->menu_alpha));
+  memset (dec->subtitle_index, 0, sizeof (dec->subtitle_index));
+  memset (dec->subtitle_alpha, 0, sizeof (dec->subtitle_alpha));
   memcpy (dec->current_clut, default_clut, sizeof (guint32) * 16);
 
   gst_setup_palette (dec);
@@ -163,8 +169,8 @@ gst_dvd_sub_dec_init (GstDvdSubDec * dec, GstDvdSubDecClass * klass)
   dec->next_ts = 0;
   dec->next_event_ts = GST_CLOCK_TIME_NONE;
 
+  dec->out_buffer = NULL;
   dec->buf_dirty = TRUE;
-  dec->use_ARGB = FALSE;
 }
 
 static void
@@ -315,10 +321,16 @@ gst_dvd_sub_dec_parse_subpic (GstDvdSubDec * dec)
       case SPU_SET_SIZE:       /* image coordinates */
         PARSE_BYTES_NEEDED (7);
 
-        dec->top = ((buf[4] & 0x3f) << 4) | ((buf[5] & 0xe0) >> 4);
-        dec->left = ((buf[1] & 0x3f) << 4) | ((buf[2] & 0xf0) >> 4);
-        dec->right = ((buf[2] & 0x03) << 8) | buf[3];
-        dec->bottom = ((buf[5] & 0x03) << 8) | buf[6];
+        dec->left =
+            CLAMP ((((guint) buf[1]) << 4) | (buf[2] >> 4), 0,
+            (dec->in_width - 1));
+        dec->top =
+            CLAMP ((((guint) buf[4]) << 4) | (buf[5] >> 4), 0,
+            (dec->in_height - 1));
+        dec->right =
+            CLAMP ((((buf[2] & 0x0f) << 8) | buf[3]), 0, (dec->in_width - 1));
+        dec->bottom =
+            CLAMP ((((buf[5] & 0x0f) << 8) | buf[6]), 0, (dec->in_height - 1));
 
         GST_DEBUG_OBJECT (dec, "SPU SET_SIZE left %d, top %d, right %d, "
             "bottom %d", dec->left, dec->top, dec->right, dec->bottom);
@@ -361,8 +373,7 @@ gst_dvd_sub_dec_parse_subpic (GstDvdSubDec * dec)
           event_time = gst_util_uint64_scale (ticks, 1024 * GST_SECOND, 90000);
 
           GST_DEBUG_OBJECT (dec,
-              "Next DCSQ at offset %u, delay %g secs (%d ticks)",
-              (guint) (buf - start),
+              "Next DCSQ at offset %d, delay %g secs (%d ticks)", buf - start,
               gst_util_guint64_to_gdouble (event_time / GST_SECOND), ticks);
 
           dec->parse_pos = buf;
@@ -410,49 +421,21 @@ gst_setup_palette (GstDvdSubDec * dec)
 {
   gint i;
   guint32 col;
-  Color_val *target_yuv = dec->palette_cache_yuv;
-  Color_val *target2_yuv = dec->hl_palette_cache_yuv;
-  Color_val *target_rgb = dec->palette_cache_rgb;
-  Color_val *target2_rgb = dec->hl_palette_cache_rgb;
+  YUVA_val *target = dec->palette_cache;
+  YUVA_val *target2 = dec->hl_palette_cache;
 
-  for (i = 0; i < 4; i++, target2_yuv++, target_yuv++) {
+  for (i = 0; i < 4; i++, target2++, target++) {
     col = dec->current_clut[dec->subtitle_index[i]];
-    target_yuv->Y_R = (col >> 16) & 0xff;
-    target_yuv->V_B = (col >> 8) & 0xff;
-    target_yuv->U_G = col & 0xff;
-    target_yuv->A = dec->subtitle_alpha[i] * 0xff / 0xf;
+    target->Y = (col >> 16) & 0xff;
+    target->V = (col >> 8) & 0xff;
+    target->U = col & 0xff;
+    target->A = dec->subtitle_alpha[i] * 0xff / 0xf;
 
     col = dec->current_clut[dec->menu_index[i]];
-    target2_yuv->Y_R = (col >> 16) & 0xff;
-    target2_yuv->V_B = (col >> 8) & 0xff;
-    target2_yuv->U_G = col & 0xff;
-    target2_yuv->A = dec->menu_alpha[i] * 0xff / 0xf;
-
-    /* If ARGB flag set, then convert YUV palette to RGB */
-    /* Using integer aritmetic */
-    if (dec->use_ARGB) {
-      guchar C = target_yuv->Y_R - 16;
-      guchar D = target_yuv->U_G - 128;
-      guchar E = target_yuv->V_B - 128;
-
-      target_rgb->Y_R = CLAMP (((298 * C + 409 * E + 128) >> 8), 0, 255);
-      target_rgb->U_G =
-          CLAMP (((298 * C - 100 * D - 128 * E + 128) >> 8), 0, 255);
-      target_rgb->V_B = CLAMP (((298 * C + 516 * D + 128) >> 8), 0, 255);
-      target_rgb->A = target_yuv->A;
-
-      C = target2_yuv->Y_R - 16;
-      D = target2_yuv->U_G - 128;
-      E = target2_yuv->V_B - 128;
-
-      target2_rgb->Y_R = CLAMP (((298 * C + 409 * E + 128) >> 8), 0, 255);
-      target2_rgb->U_G =
-          CLAMP (((298 * C - 100 * D - 128 * E + 128) >> 8), 0, 255);
-      target2_rgb->V_B = CLAMP (((298 * C + 516 * D + 128) >> 8), 0, 255);
-      target2_rgb->A = target2_yuv->A;
-    }
-    target_rgb++;
-    target2_rgb++;
+    target2->Y = (col >> 16) & 0xff;
+    target2->V = (col >> 8) & 0xff;
+    target2->U = col & 0xff;
+    target2->A = dec->menu_alpha[i] * 0xff / 0xf;
   }
 }
 
@@ -476,13 +459,13 @@ gst_get_rle_code (guchar * buffer, RLE_state * state)
 
 #define DRAW_RUN(target,len,c)                  \
 G_STMT_START {                                  \
-  gint i = 0;                                   \
   if ((c)->A) {                                 \
+    gint i;                                     \
     for (i = 0; i < (len); i++) {               \
       *(target)++ = (c)->A;                     \
-      *(target)++ = (c)->Y_R;                   \
-      *(target)++ = (c)->U_G;                   \
-      *(target)++ = (c)->V_B;                   \
+      *(target)++ = (c)->Y;                     \
+      *(target)++ = (c)->U;                     \
+      *(target)++ = (c)->V;                     \
     }                                           \
   } else {                                      \
     (target) += 4 * (len);                      \
@@ -491,7 +474,7 @@ G_STMT_START {                                  \
 
 /* 
  * This function steps over each run-length segment, drawing 
- * into the YUVA/ARGB buffers as it goes. UV are composited and then output
+ * into the YUVA buffers as it goes. UV are composited and then output
  * at half width/height
  */
 static void
@@ -509,15 +492,12 @@ gst_draw_rle_line (GstDvdSubDec * dec, guchar * buffer, RLE_state * state)
 
   while (x < right) {
     gboolean in_hl;
-    const Color_val *colour_entry;
+    const YUVA_val *colour_entry;
 
     code = gst_get_rle_code (buffer, state);
     length = code >> 2;
     colourid = code & 3;
-    if (dec->use_ARGB)
-      colour_entry = dec->palette_cache_rgb + colourid;
-    else
-      colour_entry = dec->palette_cache_yuv + colourid;
+    colour_entry = dec->palette_cache + colourid;
 
     /* Length = 0 implies fill to the end of the line */
     /* Restrict the colour run to the end of the line */
@@ -540,11 +520,7 @@ gst_draw_rle_line (GstDvdSubDec * dec, guchar * buffer, RLE_state * state)
 
       /* Draw across the highlight region */
       if (x <= state->hl_right) {
-        const Color_val *hl_colour;
-        if (dec->use_ARGB)
-          hl_colour = dec->hl_palette_cache_rgb + colourid;
-        else
-          hl_colour = dec->hl_palette_cache_yuv + colourid;
+        const YUVA_val *hl_colour = dec->hl_palette_cache + colourid;
 
         run = MIN (length, state->hl_right - x + 1);
 
@@ -586,50 +562,6 @@ gst_dvd_sub_dec_merge_title (GstDvdSubDec * dec, GstBuffer * buf)
   state.offset[0] = dec->offset[0];
   state.offset[1] = dec->offset[1];
 
-  /* center the image when display rectangle exceeds the video width */
-  if (dec->in_width <= dec->right) {
-    gint left, disp_width;
-
-    disp_width = dec->right - dec->left + 1;
-    left = (dec->in_width - disp_width) / 2;
-    dec->left = left;
-    dec->right = left + disp_width - 1;
-
-    /* if it clips to the right, shift it left, but only till zero */
-    if (dec->right >= dec->in_width) {
-      gint shift = dec->right - dec->in_width - 1;
-      if (shift > dec->left)
-        shift = dec->left;
-      dec->left -= shift;
-      dec->right -= shift;
-    }
-
-    GST_DEBUG_OBJECT (dec, "clipping width to %d,%d",
-        dec->left, dec->in_width - 1);
-  }
-
-  /* for the height, bring it up till it fits as well as it can. We
-   * assume the picture is in the lower part. We should better check where it
-   * is and do something more clever. */
-  if (dec->in_height <= dec->bottom) {
-
-    /* shift it up, but only till zero */
-    gint shift = dec->bottom - dec->in_height - 1;
-    if (shift > dec->top)
-      shift = dec->top;
-    dec->top -= shift;
-    dec->bottom -= shift;
-
-    /* start on even line */
-    if (dec->top & 1) {
-      dec->top--;
-      dec->bottom--;
-    }
-
-    GST_DEBUG_OBJECT (dec, "clipping height to %d,%d",
-        dec->top, dec->in_height - 1);
-  }
-
   if (dec->current_button) {
     hl_top = dec->hl_top;
     hl_bottom = dec->hl_bottom;
@@ -687,56 +619,52 @@ gst_send_subtitle_frame (GstDvdSubDec * dec, GstClockTime end_ts)
   g_assert (dec->next_ts <= end_ts);
 
   /* Check if we need to redraw the output buffer */
-  if (!dec->buf_dirty) {
-    flow = GST_FLOW_OK;
-    goto out;
-  }
+  if (dec->buf_dirty) {
+    if (dec->out_buffer) {
+      gst_buffer_unref (dec->out_buffer);
+      dec->out_buffer = NULL;
+    }
 
-  flow = gst_pad_alloc_buffer_and_set_caps (dec->srcpad, 0,
-      4 * dec->in_width * dec->in_height, GST_PAD_CAPS (dec->srcpad), &out_buf);
+    flow = gst_pad_alloc_buffer_and_set_caps (dec->srcpad, 0,
+        4 * dec->in_width * dec->in_height, GST_PAD_CAPS (dec->srcpad),
+        &out_buf);
 
-  if (flow != GST_FLOW_OK) {
-    GST_DEBUG_OBJECT (dec, "alloc buffer failed: flow = %s",
-        gst_flow_get_name (flow));
-    goto out;
-  }
+    if (flow != GST_FLOW_OK) {
+      GST_DEBUG_OBJECT (dec, "alloc buffer failed: flow = %s",
+          gst_flow_get_name (flow));
+      goto out;
+    }
 
-  /* Clear the buffer */
-  /* FIXME - move this into the buffer rendering code */
-  for (y = 0; y < dec->in_height; y++) {
-    guchar *line = GST_BUFFER_DATA (out_buf) + 4 * dec->in_width * y;
+    /* Clear the buffer */
+    /* FIXME - move this into the buffer rendering code */
+    for (y = 0; y < dec->in_height; y++) {
+      guchar *line = GST_BUFFER_DATA (out_buf) + 4 * dec->in_width * y;
 
-    for (x = 0; x < dec->in_width; x++) {
-      line[0] = 0;              /* A */
-      if (!dec->use_ARGB) {
+      for (x = 0; x < dec->in_width; x++) {
+        line[0] = 0;            /* A */
         line[1] = 16;           /* Y */
         line[2] = 128;          /* U */
         line[3] = 128;          /* V */
-      } else {
-        line[1] = 0;            /* R */
-        line[2] = 0;            /* G */
-        line[3] = 0;            /* B */
+
+        line += 4;
       }
-
-      line += 4;
     }
+
+    /* FIXME: do we really want to honour the forced_display flag
+     * for subtitles streans? */
+    if (dec->visible || dec->forced_display) {
+      gst_dvd_sub_dec_merge_title (dec, out_buf);
+    }
+
+    dec->out_buffer = out_buf;
+    dec->buf_dirty = FALSE;
   }
 
-  /* FIXME: do we really want to honour the forced_display flag
-   * for subtitles streans? */
-  if (dec->visible || dec->forced_display) {
-    gst_dvd_sub_dec_merge_title (dec, out_buf);
-  }
-
-  dec->buf_dirty = FALSE;
+  out_buf = gst_buffer_create_sub (dec->out_buffer, 0,
+      GST_BUFFER_SIZE (dec->out_buffer));
 
   GST_BUFFER_TIMESTAMP (out_buf) = dec->next_ts;
-  if (GST_CLOCK_TIME_IS_VALID (dec->next_event_ts)) {
-    GST_BUFFER_DURATION (out_buf) = GST_CLOCK_DIFF (dec->next_ts,
-        dec->next_event_ts);
-  } else {
-    GST_BUFFER_DURATION (out_buf) = GST_CLOCK_TIME_NONE;
-  }
+  GST_BUFFER_DURATION (out_buf) = GST_CLOCK_DIFF (dec->next_ts, end_ts);
 
   GST_DEBUG_OBJECT (dec, "Sending subtitle buffer with ts %"
       GST_TIME_FORMAT ", dur %" G_GINT64_FORMAT,
@@ -748,6 +676,7 @@ gst_send_subtitle_frame (GstDvdSubDec * dec, GstClockTime end_ts)
   flow = gst_pad_push (dec->srcpad, out_buf);
 
 out:
+
   dec->next_ts = end_ts;
   return flow;
 }
@@ -867,78 +796,6 @@ gst_dvd_sub_dec_chain (GstPad * pad, GstBuffer * buf)
   return ret;
 }
 
-static gboolean
-gst_dvd_sub_dec_sink_setcaps (GstPad * pad, GstCaps * caps)
-{
-  GstDvdSubDec *dec = GST_DVD_SUB_DEC (gst_pad_get_parent (pad));
-  gboolean ret = FALSE;
-  guint32 fourcc = GST_MAKE_FOURCC ('A', 'Y', 'U', 'V');
-  GstCaps *out_caps = NULL, *peer_caps = NULL;
-
-  GST_DEBUG_OBJECT (dec, "setcaps called with %" GST_PTR_FORMAT, caps);
-
-  dec->out_fourcc = fourcc;
-  out_caps = gst_caps_new_simple ("video/x-raw-yuv",
-      "width", G_TYPE_INT, dec->in_width,
-      "height", G_TYPE_INT, dec->in_height,
-      "format", GST_TYPE_FOURCC, dec->out_fourcc,
-      "framerate", GST_TYPE_FRACTION, 0, 1, NULL);
-
-  peer_caps = gst_pad_get_allowed_caps (dec->srcpad);
-  if (G_LIKELY (peer_caps)) {
-    guint i = 0, n = 0;
-    n = gst_caps_get_size (peer_caps);
-    GST_DEBUG_OBJECT (dec, "peer allowed caps (%u structure(s)) are %"
-        GST_PTR_FORMAT, n, peer_caps);
-
-    for (i = 0; i < n; i++) {
-      GstStructure *s = gst_caps_get_structure (peer_caps, i);
-      /* Check if the peer pad support ARGB format, if yes change caps */
-      if (gst_structure_has_name (s, "video/x-raw-rgb") &&
-          gst_structure_has_field (s, "alpha_mask")) {
-        gst_caps_unref (out_caps);
-        GST_DEBUG_OBJECT (dec, "trying with fourcc %" GST_FOURCC_FORMAT,
-            GST_FOURCC_ARGS (fourcc));
-        out_caps = gst_caps_new_simple ("video/x-raw-rgb",
-            "width", G_TYPE_INT, dec->in_width,
-            "height", G_TYPE_INT, dec->in_height,
-            "framerate", GST_TYPE_FRACTION, 0, 1,
-            "bpp", G_TYPE_INT, 32,
-            "depth", G_TYPE_INT, 32,
-            "red_mask", G_TYPE_INT, 16711680,
-            "green_mask", G_TYPE_INT, 65280,
-            "blue_mask", G_TYPE_INT, 255,
-            "alpha_mask", G_TYPE_INT, -16777216,
-            "endianness", G_TYPE_INT, G_BIG_ENDIAN, NULL);
-        if (gst_pad_peer_accept_caps (dec->srcpad, out_caps)) {
-          GST_DEBUG_OBJECT (dec, "peer accepted format %" GST_FOURCC_FORMAT,
-              GST_FOURCC_ARGS (fourcc));
-          /* If ARGB format then set the flag */
-          dec->use_ARGB = TRUE;
-          break;
-        }
-      }
-    }
-    gst_caps_unref (peer_caps);
-  }
-  GST_DEBUG_OBJECT (dec, "setting caps downstream to %" GST_PTR_FORMAT,
-      out_caps);
-  if (gst_pad_set_caps (dec->srcpad, out_caps)) {
-    dec->out_fourcc = fourcc;
-  } else {
-    GST_WARNING_OBJECT (dec, "failed setting downstream caps");
-    gst_caps_unref (out_caps);
-    goto beach;
-  }
-
-  gst_caps_unref (out_caps);
-  ret = TRUE;
-
-beach:
-  gst_object_unref (dec);
-  return ret;
-}
-
 static gboolean
 gst_dvd_sub_dec_sink_event (GstPad * pad, GstEvent * event)
 {
@@ -1049,8 +906,7 @@ gst_dvd_sub_dec_handle_dvd_event (GstDvdSubDec * dec, GstEvent * event)
 
   event_name = gst_structure_get_string (structure, "event");
 
-  GST_LOG_OBJECT (dec,
-      "DVD event %s with timestamp %" G_GINT64_FORMAT " on sub pad",
+  GST_LOG_OBJECT (dec, "DVD event %s with timestamp %lld on sub pad",
       GST_STR_NULL (event_name), GST_EVENT_TIMESTAMP (event));
 
   if (event_name == NULL)
@@ -1135,14 +991,12 @@ static gboolean
 plugin_init (GstPlugin * plugin)
 {
   if (!gst_element_register (plugin, "dvdsubdec", GST_RANK_NONE,
-          GST_TYPE_DVD_SUB_DEC) ||
-      !gst_element_register (plugin, "dvdsubparse", GST_RANK_NONE,
-          GST_TYPE_DVD_SUB_PARSE)) {
+          GST_TYPE_DVD_SUB_DEC)) {
     return FALSE;
   }
 
   GST_DEBUG_CATEGORY_INIT (gst_dvd_sub_dec_debug, "dvdsubdec", 0,
-      "DVD subtitle decoder");
+      "DVD subtitle decoder element");
 
   return TRUE;
 }
@@ -1150,5 +1004,5 @@ plugin_init (GstPlugin * plugin)
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
     GST_VERSION_MINOR,
     "dvdsub",
-    "DVD subtitle parser and decoder", plugin_init,
-    VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN);
+    "Decode DVD subtitles to AYUV video frames", plugin_init,
+    VERSION, "LGPL", GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN);
